@@ -38,8 +38,8 @@
 #include <kbuildsycocaprogressdialog.h>
 #include <klocalizedstring.h>
 
-#include <ksycoca.h>
 #include <kservicetypeprofile.h>
+#include <ksycoca.h>
 
 #include <kwindowsystem.h>
 
@@ -66,11 +66,9 @@ void FileTypeDialog::init()
     connect(m_details, &FileTypeDetails::changed, this, &FileTypeDialog::clientChanged);
 
     m_buttonBox = new QDialogButtonBox;
-    m_buttonBox->setStandardButtons(
-        QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel);
+    m_buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel);
     connect(m_buttonBox, SIGNAL(accepted()), SLOT(accept()));
-    connect(m_buttonBox->button(
-                QDialogButtonBox::Apply), &QAbstractButton::clicked, this, &FileTypeDialog::save);
+    connect(m_buttonBox->button(QDialogButtonBox::Apply), &QAbstractButton::clicked, this, &FileTypeDialog::save);
     connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     // This code is very similar to kcdialog.cpp
@@ -81,8 +79,7 @@ void FileTypeDialog::init()
 
     setApplyButtonEnabled(false);
 
-    connect(KSycoca::self(), SIGNAL(databaseChanged(QStringList)),
-            SLOT(slotDatabaseChanged(QStringList)));
+    connect(KSycoca::self(), SIGNAL(databaseChanged(QStringList)), SLOT(slotDatabaseChanged(QStringList)));
 }
 
 void FileTypeDialog::setApplyButtonEnabled(bool enabled)
@@ -101,10 +98,8 @@ void FileTypeDialog::save()
             KBuildSycocaProgressDialog::rebuildKSycoca(this);
         }
         // Trigger reparseConfiguration of filetypesrc in konqueror
-        QDBusMessage message
-            = QDBusMessage::createSignal(QStringLiteral("/KonqMain"),
-                                         QStringLiteral("org.kde.Konqueror.Main"),
-                                         QStringLiteral("reparseConfiguration"));
+        QDBusMessage message =
+            QDBusMessage::createSignal(QStringLiteral("/KonqMain"), QStringLiteral("org.kde.Konqueror.Main"), QStringLiteral("reparseConfiguration"));
         QDBusConnection::sessionBus().send(message);
     }
 }
@@ -124,8 +119,8 @@ void FileTypeDialog::clientChanged(bool state)
 void FileTypeDialog::slotDatabaseChanged(const QStringList &changedResources)
 {
     qDebug() << changedResources;
-    if (changedResources.contains(QStringLiteral("xdgdata-mime"))  // changes in mimetype definitions
-        || changedResources.contains(QStringLiteral("services"))) {   // changes in .desktop files
+    if (changedResources.contains(QStringLiteral("xdgdata-mime")) // changes in mimetype definitions
+        || changedResources.contains(QStringLiteral("services"))) { // changes in .desktop files
         m_details->refresh();
     }
 }
@@ -134,13 +129,12 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral(
-                                                     "preferences-desktop-filetype-association")));
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-filetype-association")));
 
-    KAboutData aboutData(QStringLiteral("keditfiletype"), i18n("File Type Editor"),
+    KAboutData aboutData(QStringLiteral("keditfiletype"),
+                         i18n("File Type Editor"),
                          QLatin1String(PROJECT_VERSION),
-                         i18n(
-                             "KDE file type editor - simplified version for editing a single file type"),
+                         i18n("KDE file type editor - simplified version for editing a single file type"),
                          KAboutLicense::GPL,
                          i18n("(c) 2000, KDE developers"));
     aboutData.addAuthor(i18n("Preston Brown"), QString(), QStringLiteral("pbrown@kde.org"));
@@ -150,10 +144,9 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("parent"),
-        i18n("Makes the dialog transient for the window specified by winid"),
-    QStringLiteral("winid")));
-    parser.addPositionalArgument(QStringLiteral("mimetype"),
-                                 i18n("File type to edit (e.g. text/html)"));
+                                        i18n("Makes the dialog transient for the window specified by winid"),
+                                        QStringLiteral("winid")));
+    parser.addPositionalArgument(QStringLiteral("mimetype"), i18n("File type to edit (e.g. text/html)"));
 
     parser.process(app);
     aboutData.processCommandLine(&parser);
