@@ -9,7 +9,7 @@
  * published by the Free Software Foundation; either version 2 of
  * the License or (at your option) version 3 or any later version
  * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy 
+ * by the membership of KDE e.V.), which shall act as a proxy
  * defined in Section 14 of version 3 of the license.
 
  * This program is distributed in the hope that it will be useful,
@@ -27,22 +27,22 @@
 
 #include <QWidget>
 
-class KStart: public QObject {
-  Q_OBJECT
+class KStart : public QObject
+{
+    Q_OBJECT
 
 public:
-  KStart();
-  ~KStart() override {}
-  
+    KStart();
+    ~KStart() override
+    {
+    }
+
 public Q_SLOTS:
-  void windowAdded(WId);
+    void windowAdded(WId);
 
 private:
-
-  void applyStyle(WId );
-  void sendRule();
-
+    void applyStyle(WId);
+    void sendRule();
 };
 
 #endif
-
